require "minodes/sinatra/logger/version"
require "sinatra"
require "rack"
require 'rack/body_proxy'
require 'rack/utils'
require "semantic_logger"
require "logger"

module Minodes
  module Sinatra
    class ErrorLogger
      def puts(msg)
        SemanticLogger["Error"].error msg
      end

      def flush
        SemanticLogger.flush
      end

      def <<(msg)
        # To satisfy test calls. This function is available on "Logger" class by default.
      end
    end

    module Logger
      ::Sinatra::Base.class_eval do
        def self.logger(config)
          if config[:filename].nil?
            raise "Minodes::Sinatra::Logger -- File name is not specified. Please, set `file_name` in the configuration block!"
          end

          config[:level] ||= :trace

          set :logging, true
          use ::Rack::CommonLogger, ::SemanticLogger["Access"]

          ::Sinatra::Base.before do
            ::SemanticLogger.default_level = config[:level]
            ::SemanticLogger.appenders.each { |a| ::SemanticLogger.remove_appender(a) }
            ::SemanticLogger.add_appender(file_name: config[:filename], formatter: :color)

            env["rack.errors"] = ::Minodes::Sinatra::ErrorLogger.new
            env["rack.logger"] = ::SemanticLogger[self.class.name]
          end
        end
      end
    end
  end
end
